# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['TemDomainValidationArgs', 'TemDomainValidation']

@pulumi.input_type
class TemDomainValidationArgs:
    def __init__(__self__, *,
                 domain_id: pulumi.Input[_builtins.str],
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a TemDomainValidation resource.
        :param pulumi.Input[_builtins.str] domain_id: The ID of the domain name used when sending emails. This ID must correspond to a domain already registered with Scaleway's Transactional Email service.
        :param pulumi.Input[_builtins.str] region: `region`). Specifies the region where the domain is registered. If not specified, it defaults to the provider's region.
        :param pulumi.Input[_builtins.int] timeout: The maximum wait time in seconds before returning an error if the domain validation does not complete. The default is 300 seconds.
        """
        pulumi.set(__self__, "domain_id", domain_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the domain name used when sending emails. This ID must correspond to a domain already registered with Scaleway's Transactional Email service.
        """
        return pulumi.get(self, "domain_id")

    @domain_id.setter
    def domain_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "domain_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`). Specifies the region where the domain is registered. If not specified, it defaults to the provider's region.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum wait time in seconds before returning an error if the domain validation does not complete. The default is 300 seconds.
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout", value)


@pulumi.input_type
class _TemDomainValidationState:
    def __init__(__self__, *,
                 domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 validated: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering TemDomainValidation resources.
        :param pulumi.Input[_builtins.str] domain_id: The ID of the domain name used when sending emails. This ID must correspond to a domain already registered with Scaleway's Transactional Email service.
        :param pulumi.Input[_builtins.str] region: `region`). Specifies the region where the domain is registered. If not specified, it defaults to the provider's region.
        :param pulumi.Input[_builtins.int] timeout: The maximum wait time in seconds before returning an error if the domain validation does not complete. The default is 300 seconds.
        :param pulumi.Input[_builtins.bool] validated: Indicates if the domain has been verified for email sending. This is computed after the creation or update of the domain validation resource.
        """
        if domain_id is not None:
            pulumi.set(__self__, "domain_id", domain_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)
        if validated is not None:
            pulumi.set(__self__, "validated", validated)

    @_builtins.property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the domain name used when sending emails. This ID must correspond to a domain already registered with Scaleway's Transactional Email service.
        """
        return pulumi.get(self, "domain_id")

    @domain_id.setter
    def domain_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`). Specifies the region where the domain is registered. If not specified, it defaults to the provider's region.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum wait time in seconds before returning an error if the domain validation does not complete. The default is 300 seconds.
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout", value)

    @_builtins.property
    @pulumi.getter
    def validated(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the domain has been verified for email sending. This is computed after the creation or update of the domain validation resource.
        """
        return pulumi.get(self, "validated")

    @validated.setter
    def validated(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "validated", value)


warnings.warn("""scaleway.index/temdomainvalidation.TemDomainValidation has been deprecated in favor of scaleway.tem/domainvalidation.DomainValidation""", DeprecationWarning)


@pulumi.type_token("scaleway:index/temDomainValidation:TemDomainValidation")
class TemDomainValidation(pulumi.CustomResource):
    warnings.warn("""scaleway.index/temdomainvalidation.TemDomainValidation has been deprecated in favor of scaleway.tem/domainvalidation.DomainValidation""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.tem.Domain("main",
            accept_tos=True,
            name="example.com")
        example = scaleway.tem.DomainValidation("example",
            domain_id=main.id,
            region="fr-par",
            timeout=300)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain_id: The ID of the domain name used when sending emails. This ID must correspond to a domain already registered with Scaleway's Transactional Email service.
        :param pulumi.Input[_builtins.str] region: `region`). Specifies the region where the domain is registered. If not specified, it defaults to the provider's region.
        :param pulumi.Input[_builtins.int] timeout: The maximum wait time in seconds before returning an error if the domain validation does not complete. The default is 300 seconds.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TemDomainValidationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.tem.Domain("main",
            accept_tos=True,
            name="example.com")
        example = scaleway.tem.DomainValidation("example",
            domain_id=main.id,
            region="fr-par",
            timeout=300)
        ```

        :param str resource_name: The name of the resource.
        :param TemDomainValidationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TemDomainValidationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        pulumi.log.warn("""TemDomainValidation is deprecated: scaleway.index/temdomainvalidation.TemDomainValidation has been deprecated in favor of scaleway.tem/domainvalidation.DomainValidation""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TemDomainValidationArgs.__new__(TemDomainValidationArgs)

            if domain_id is None and not opts.urn:
                raise TypeError("Missing required property 'domain_id'")
            __props__.__dict__["domain_id"] = domain_id
            __props__.__dict__["region"] = region
            __props__.__dict__["timeout"] = timeout
            __props__.__dict__["validated"] = None
        super(TemDomainValidation, __self__).__init__(
            'scaleway:index/temDomainValidation:TemDomainValidation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            domain_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            timeout: Optional[pulumi.Input[_builtins.int]] = None,
            validated: Optional[pulumi.Input[_builtins.bool]] = None) -> 'TemDomainValidation':
        """
        Get an existing TemDomainValidation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain_id: The ID of the domain name used when sending emails. This ID must correspond to a domain already registered with Scaleway's Transactional Email service.
        :param pulumi.Input[_builtins.str] region: `region`). Specifies the region where the domain is registered. If not specified, it defaults to the provider's region.
        :param pulumi.Input[_builtins.int] timeout: The maximum wait time in seconds before returning an error if the domain validation does not complete. The default is 300 seconds.
        :param pulumi.Input[_builtins.bool] validated: Indicates if the domain has been verified for email sending. This is computed after the creation or update of the domain validation resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TemDomainValidationState.__new__(_TemDomainValidationState)

        __props__.__dict__["domain_id"] = domain_id
        __props__.__dict__["region"] = region
        __props__.__dict__["timeout"] = timeout
        __props__.__dict__["validated"] = validated
        return TemDomainValidation(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the domain name used when sending emails. This ID must correspond to a domain already registered with Scaleway's Transactional Email service.
        """
        return pulumi.get(self, "domain_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`). Specifies the region where the domain is registered. If not specified, it defaults to the provider's region.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The maximum wait time in seconds before returning an error if the domain validation does not complete. The default is 300 seconds.
        """
        return pulumi.get(self, "timeout")

    @_builtins.property
    @pulumi.getter
    def validated(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates if the domain has been verified for email sending. This is computed after the creation or update of the domain validation resource.
        """
        return pulumi.get(self, "validated")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetConsumptionsConsumptionResult',
    'GetInvoicesInvoiceResult',
]

@pulumi.output_type
class GetConsumptionsConsumptionResult(dict):
    def __init__(__self__, *,
                 billed_quantity: _builtins.str,
                 category_name: _builtins.str,
                 product_name: _builtins.str,
                 project_id: _builtins.str,
                 sku: _builtins.str,
                 unit: _builtins.str,
                 value: _builtins.str):
        """
        :param _builtins.str billed_quantity: The consumed quantity.
        :param _builtins.str category_name: The name of the consumption category.
        :param _builtins.str product_name: The product name.
        :param _builtins.str project_id: `project_id`) The ID of the project the consumption list is associated with.
        :param _builtins.str sku: The unique identifier of the product.
        :param _builtins.str unit: The unit of consumed quantity.
        :param _builtins.str value: The monetary value of the consumption.
        """
        pulumi.set(__self__, "billed_quantity", billed_quantity)
        pulumi.set(__self__, "category_name", category_name)
        pulumi.set(__self__, "product_name", product_name)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "sku", sku)
        pulumi.set(__self__, "unit", unit)
        pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="billedQuantity")
    def billed_quantity(self) -> _builtins.str:
        """
        The consumed quantity.
        """
        return pulumi.get(self, "billed_quantity")

    @_builtins.property
    @pulumi.getter(name="categoryName")
    def category_name(self) -> _builtins.str:
        """
        The name of the consumption category.
        """
        return pulumi.get(self, "category_name")

    @_builtins.property
    @pulumi.getter(name="productName")
    def product_name(self) -> _builtins.str:
        """
        The product name.
        """
        return pulumi.get(self, "product_name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        `project_id`) The ID of the project the consumption list is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def sku(self) -> _builtins.str:
        """
        The unique identifier of the product.
        """
        return pulumi.get(self, "sku")

    @_builtins.property
    @pulumi.getter
    def unit(self) -> _builtins.str:
        """
        The unit of consumed quantity.
        """
        return pulumi.get(self, "unit")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        """
        The monetary value of the consumption.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetInvoicesInvoiceResult(dict):
    def __init__(__self__, *,
                 billing_period: _builtins.str,
                 due_date: _builtins.str,
                 id: _builtins.str,
                 invoice_type: _builtins.str,
                 issued_date: _builtins.str,
                 number: _builtins.int,
                 organization_name: _builtins.str,
                 seller_name: _builtins.str,
                 start_date: _builtins.str,
                 state: _builtins.str,
                 stop_date: _builtins.str,
                 total_discount: _builtins.str,
                 total_tax: _builtins.str,
                 total_taxed: _builtins.str,
                 total_undiscount: _builtins.str,
                 total_untaxed: _builtins.str):
        """
        :param _builtins.str billing_period: The billing period of the invoice in the YYYY-MM format.
        :param _builtins.str due_date: The payment time limit, set according to the Organization's payment conditions (RFC 3339 format).
        :param _builtins.str id: The associated invoice ID.
        :param _builtins.str invoice_type: Invoices with the given type are listed. Valid values are `periodic` and `purchase`.
        :param _builtins.str issued_date: The date when the invoice was sent to the customer (RFC 3339 format).
        :param _builtins.int number: The invoice number.
        :param _builtins.str organization_name: The organization name.
        :param _builtins.str seller_name: The name of the seller (Scaleway).
        :param _builtins.str start_date: The start date of the billing period (RFC 3339 format).
        :param _builtins.str state: The state of the invoice.
        :param _builtins.str stop_date: The end date of the billing period (RFC 3339 format).
        :param _builtins.str total_discount: The total discount amount of the invoice.
        :param _builtins.str total_tax: The total tax amount of the invoice.
        :param _builtins.str total_taxed: The total amount, taxed.
        :param _builtins.str total_undiscount: The total amount of the invoice before applying the discount.
        :param _builtins.str total_untaxed: The total amount, untaxed.
        """
        pulumi.set(__self__, "billing_period", billing_period)
        pulumi.set(__self__, "due_date", due_date)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "invoice_type", invoice_type)
        pulumi.set(__self__, "issued_date", issued_date)
        pulumi.set(__self__, "number", number)
        pulumi.set(__self__, "organization_name", organization_name)
        pulumi.set(__self__, "seller_name", seller_name)
        pulumi.set(__self__, "start_date", start_date)
        pulumi.set(__self__, "state", state)
        pulumi.set(__self__, "stop_date", stop_date)
        pulumi.set(__self__, "total_discount", total_discount)
        pulumi.set(__self__, "total_tax", total_tax)
        pulumi.set(__self__, "total_taxed", total_taxed)
        pulumi.set(__self__, "total_undiscount", total_undiscount)
        pulumi.set(__self__, "total_untaxed", total_untaxed)

    @_builtins.property
    @pulumi.getter(name="billingPeriod")
    def billing_period(self) -> _builtins.str:
        """
        The billing period of the invoice in the YYYY-MM format.
        """
        return pulumi.get(self, "billing_period")

    @_builtins.property
    @pulumi.getter(name="dueDate")
    def due_date(self) -> _builtins.str:
        """
        The payment time limit, set according to the Organization's payment conditions (RFC 3339 format).
        """
        return pulumi.get(self, "due_date")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The associated invoice ID.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="invoiceType")
    def invoice_type(self) -> _builtins.str:
        """
        Invoices with the given type are listed. Valid values are `periodic` and `purchase`.
        """
        return pulumi.get(self, "invoice_type")

    @_builtins.property
    @pulumi.getter(name="issuedDate")
    def issued_date(self) -> _builtins.str:
        """
        The date when the invoice was sent to the customer (RFC 3339 format).
        """
        return pulumi.get(self, "issued_date")

    @_builtins.property
    @pulumi.getter
    def number(self) -> _builtins.int:
        """
        The invoice number.
        """
        return pulumi.get(self, "number")

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> _builtins.str:
        """
        The organization name.
        """
        return pulumi.get(self, "organization_name")

    @_builtins.property
    @pulumi.getter(name="sellerName")
    def seller_name(self) -> _builtins.str:
        """
        The name of the seller (Scaleway).
        """
        return pulumi.get(self, "seller_name")

    @_builtins.property
    @pulumi.getter(name="startDate")
    def start_date(self) -> _builtins.str:
        """
        The start date of the billing period (RFC 3339 format).
        """
        return pulumi.get(self, "start_date")

    @_builtins.property
    @pulumi.getter
    def state(self) -> _builtins.str:
        """
        The state of the invoice.
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter(name="stopDate")
    def stop_date(self) -> _builtins.str:
        """
        The end date of the billing period (RFC 3339 format).
        """
        return pulumi.get(self, "stop_date")

    @_builtins.property
    @pulumi.getter(name="totalDiscount")
    def total_discount(self) -> _builtins.str:
        """
        The total discount amount of the invoice.
        """
        return pulumi.get(self, "total_discount")

    @_builtins.property
    @pulumi.getter(name="totalTax")
    def total_tax(self) -> _builtins.str:
        """
        The total tax amount of the invoice.
        """
        return pulumi.get(self, "total_tax")

    @_builtins.property
    @pulumi.getter(name="totalTaxed")
    def total_taxed(self) -> _builtins.str:
        """
        The total amount, taxed.
        """
        return pulumi.get(self, "total_taxed")

    @_builtins.property
    @pulumi.getter(name="totalUndiscount")
    def total_undiscount(self) -> _builtins.str:
        """
        The total amount of the invoice before applying the discount.
        """
        return pulumi.get(self, "total_undiscount")

    @_builtins.property
    @pulumi.getter(name="totalUntaxed")
    def total_untaxed(self) -> _builtins.str:
        """
        The total amount, untaxed.
        """
        return pulumi.get(self, "total_untaxed")


